/***************************************************************************
                          job_modifyfavourite.h  -  description
                             -------------------
    begin                : Wed May 9 2001
    copyright            : (C) 2001 by Holger Sattel
    email                : hsattel@rumms.uni-mannheim.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef JOB_PLAYALBUM_H
#define JOB_PLAYALBUM_H

#include "prokyon.h"

#include "jobbase.h"

class Job_PlayAlbum : public JobBase  {
public:

    Job_PlayAlbum(int type, QString data, QString data2 );

    void run();

    int type() {
        return JOB_PLAYALBUM;
    }

    ~Job_PlayAlbum() {
        ;
    }

private:
    int querytype;
    QString querydata,querydata2;
};

#endif
